package com.persagy.dmp.rwd.simple.controller;

import com.persagy.dmp.common.constant.CommonConstant;
import com.persagy.dmp.common.model.response.CommonResult;
import com.persagy.dmp.common.utils.ParamCheckUtil;
import com.persagy.dmp.common.utils.ResultHelper;
import com.persagy.dmp.rwd.digital.service.IObjectDigitalService;
import com.persagy.dmp.rwd.simple.entity.CountTypeEquipmentVO;
import com.persagy.dmp.rwd.simple.service.IEquipmentReportService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;
import java.util.Map;

/**
 * 简洁API - 设备统计相关接口
 * @author Charlie Yu
 * @date 2021-09-02
 */
@Slf4j
@RestController
@RequestMapping("/api/report/equipment")
public class EquipmentReportController {

    @Autowired
    private IObjectDigitalService digitalService;
    @Autowired
    private IEquipmentReportService reportService;

    /**
     * 统计项目设备总数和待报废设备数量
     * 待报废设备 = ifnull(预计报废日期, '9999-12-31') < (当前日期+6个月)
     * @param projectIds 为空查所有
     * @return
     */
    @PostMapping("/queryExpectScrapCountByProjects")
    public CommonResult<List<Map<String, Object>>> queryExpectScrapCountByProjects(
            @RequestBody(required = false) List<String> projectIds) {
        //基础参数校验
        ParamCheckUtil.checkParam(CommonConstant.QUERY_GROUPCODE);
        // 统计
        List<Map<String, Object>> result = reportService.queryExpectScrapCountByProjects(projectIds);
        return ResultHelper.multi(result);
    }

    /**
     * 按对象类型统计设备总数
     * @param projectIds 为空查所有
     * @return 专业类统计 - 系统类统计 - 设备类统计 层级结构
     */
    @PostMapping("/queryEquipmentCountByType")
    public CommonResult<List<CountTypeEquipmentVO>> queryEquipmentCountByType(@RequestBody(required = false) List<String> projectIds) {
        //基础参数校验
        ParamCheckUtil.checkParam(CommonConstant.QUERY_GROUPCODE);
        // 统计
        List<CountTypeEquipmentVO> result = reportService.queryEquipmentCountByType(projectIds);
        return ResultHelper.multi(result);
    }
}
